==> haskell-css-text-0.1.3.0-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-css-text.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: css-text
version: 0.1.3.0
id: css-text-0.1.3.0-1ox1PQiukRcDjjZSVIByx9
key: css-text-0.1.3.0-1ox1PQiukRcDjjZSVIByx9
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: https://github.com/yesodweb/css-text.git#readme
synopsis: CSS parser and renderer.
description:
    Please see the README and generated docs at <https://www.stackage.org/package/css-text>
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Text.CSS.Parse Text.CSS.Render
hidden-modules: Paths_css_text
abi: 673e91b01d86ef746177695ee8acde3f
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/css-text-0.1.3.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/css-text-0.1.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/css-text-0.1.3.0
hs-libraries: HScss-text-0.1.3.0-1ox1PQiukRcDjjZSVIByx9
depends:
    attoparsec-0.13.2.2-3q5ERL3MW0nFqsVUGe8u15 base-4.10.1.0
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
abi-depends: attoparsec-0.13.2.2-3q5ERL3MW0nFqsVUGe8u15=df3474e0e3506c6210b323c64f491baa
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
haddock-interfaces: /usr/share/doc/haskell-css-text/html/css-text.haddock
haddock-html: /usr/share/doc/haskell-css-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-css-text-0.1.3.0-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-css-text.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: css-text
version: 0.1.3.0
id: css-text-0.1.3.0-ESjybK5bggy2gdPoxtQtO6
key: css-text-0.1.3.0-ESjybK5bggy2gdPoxtQtO6
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: https://github.com/yesodweb/css-text.git#readme
synopsis: CSS parser and renderer.
description:
    Please see the README and generated docs at <https://www.stackage.org/package/css-text>
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Text.CSS.Parse Text.CSS.Render
hidden-modules: Paths_css_text
abi: 1a143518a710834cf270cb98572136d9
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/css-text-0.1.3.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/css-text-0.1.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/css-text-0.1.3.0
hs-libraries: HScss-text-0.1.3.0-ESjybK5bggy2gdPoxtQtO6
depends:
    attoparsec-0.13.2.2-3yh63UNuZKU6kridcBRdzv base-4.10.1.0
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
abi-depends: attoparsec-0.13.2.2-3yh63UNuZKU6kridcBRdzv=7ed301843f5485a15f31657e67db1a15
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
haddock-interfaces: /usr/share/doc/haskell-css-text/html/css-text.haddock
haddock-html: /usr/share/doc/haskell-css-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
